@@ -260,7 +260,7 @@ func TestWithDefaults(t *testing.T) {
 			targets:  append(go118FirstClassAdjustedTargets, "darwin_amd64_v2"),
 			goBinary: "go",
 		},
-		"repeatin targets": {
+		"repeating targets": {
 			build: config.Build{
 				ID:      "foo3",
 				Binary:  "foo",
@@ -465,7 +465,7 @@ func TestBuild(t *testing.T) {
 	require.ElementsMatch(t, list.List(), []*artifact.Artifact{
 		{
 			Name:   "bin/foo-v5.6.7",
-			Path:   filepath.Join("dist", "linux_amd64", "bin", "foo-v5.6.7"),
+			Path:   filepath.ToSlash(filepath.Join("dist", "linux_amd64", "bin", "foo-v5.6.7")),
 			Goos:   "linux",
 			Goarch: "amd64",
 			Type:   artifact.Binary,
@@ -478,7 +478,7 @@ func TestBuild(t *testing.T) {
 		},
 		{
 			Name:   "bin/foo-v5.6.7",
-			Path:   filepath.Join("dist", "linux_mips_softfloat", "bin", "foo-v5.6.7"),
+			Path:   filepath.ToSlash(filepath.Join("dist", "linux_mips_softfloat", "bin", "foo-v5.6.7")),
 			Goos:   "linux",
 			Goarch: "mips",
 			Gomips: "softfloat",
@@ -492,7 +492,7 @@ func TestBuild(t *testing.T) {
 		},
 		{
 			Name:   "bin/foo-v5.6.7",
-			Path:   filepath.Join("dist", "linux_mips64le_softfloat", "bin", "foo-v5.6.7"),
+			Path:   filepath.ToSlash(filepath.Join("dist", "linux_mips64le_softfloat", "bin", "foo-v5.6.7")),
 			Goos:   "linux",
 			Goarch: "mips64le",
 			Gomips: "softfloat",
@@ -506,7 +506,7 @@ func TestBuild(t *testing.T) {
 		},
 		{
 			Name:   "bin/foo-v5.6.7",
-			Path:   filepath.Join("dist", "darwin_amd64", "bin", "foo-v5.6.7"),
+			Path:   filepath.ToSlash(filepath.Join("dist", "darwin_amd64", "bin", "foo-v5.6.7")),
 			Goos:   "darwin",
 			Goarch: "amd64",
 			Type:   artifact.Binary,
@@ -519,7 +519,7 @@ func TestBuild(t *testing.T) {
 		},
 		{
 			Name:   "bin/foo-v5.6.7",
-			Path:   filepath.Join("dist", "linux_arm_6", "bin", "foo-v5.6.7"),
+			Path:   filepath.ToSlash(filepath.Join("dist", "linux_arm_6", "bin", "foo-v5.6.7")),
 			Goos:   "linux",
 			Goarch: "arm",
 			Goarm:  "6",
@@ -533,7 +533,7 @@ func TestBuild(t *testing.T) {
 		},
 		{
 			Name:   "bin/foo-v5.6.7.exe",
-			Path:   filepath.Join("dist", "windows_amd64", "bin", "foo-v5.6.7.exe"),
+			Path:   filepath.ToSlash(filepath.Join("dist", "windows_amd64", "bin", "foo-v5.6.7.exe")),
 			Goos:   "windows",
 			Goarch: "amd64",
 			Type:   artifact.Binary,
@@ -546,7 +546,7 @@ func TestBuild(t *testing.T) {
 		},
 		{
 			Name:   "bin/foo-v5.6.7.wasm",
-			Path:   filepath.Join("dist", "js_wasm", "bin", "foo-v5.6.7.wasm"),
+			Path:   filepath.ToSlash(filepath.Join("dist", "js_wasm", "bin", "foo-v5.6.7.wasm")),
 			Goos:   "js",
 			Goarch: "wasm",
 			Type:   artifact.Binary,
@@ -1418,6 +1418,35 @@ func TestOverrides(t *testing.T) {
 		}, dets)
 	})
 
+	t.Run("with goarm64 unespecified", func(t *testing.T) {
+		dets, err := withOverrides(
+			testctx.New(),
+			config.Build{
+				BuildDetails: config.BuildDetails{
+					Ldflags: []string{"original"},
+				},
+				BuildDetailsOverrides: []config.BuildDetailsOverride{
+					{
+						Goos:   "linux",
+						Goarch: "arm64",
+						BuildDetails: config.BuildDetails{
+							Ldflags: []string{"overridden"},
+						},
+					},
+				},
+			}, api.Options{
+				Goos:    "linux",
+				Goarch:  "arm64",
+				Goarm64: "v8.0",
+			},
+		)
+		require.NoError(t, err)
+		require.Equal(t, config.BuildDetails{
+			Ldflags: []string{"overridden"},
+			Env:     []string{},
+		}, dets)
+	})
+
 	t.Run("with goarm", func(t *testing.T) {
 		dets, err := withOverrides(
 			testctx.New(),
@@ -1448,6 +1477,35 @@ func TestOverrides(t *testing.T) {
 		}, dets)
 	})
 
+	t.Run("with goarm unespecified", func(t *testing.T) {
+		dets, err := withOverrides(
+			testctx.New(),
+			config.Build{
+				BuildDetails: config.BuildDetails{
+					Ldflags: []string{"original"},
+				},
+				BuildDetailsOverrides: []config.BuildDetailsOverride{
+					{
+						Goos:   "linux",
+						Goarch: "arm",
+						BuildDetails: config.BuildDetails{
+							Ldflags: []string{"overridden"},
+						},
+					},
+				},
+			}, api.Options{
+				Goos:   "linux",
+				Goarch: "arm",
+				Goarm:  "6",
+			},
+		)
+		require.NoError(t, err)
+		require.Equal(t, config.BuildDetails{
+			Ldflags: []string{"overridden"},
+			Env:     []string{},
+		}, dets)
+	})
+
 	t.Run("with gomips", func(t *testing.T) {
 		dets, err := withOverrides(
 			testctx.New(),
@@ -1478,6 +1536,35 @@ func TestOverrides(t *testing.T) {
 		}, dets)
 	})
 
+	t.Run("with gomips unespecified", func(t *testing.T) {
+		dets, err := withOverrides(
+			testctx.New(),
+			config.Build{
+				BuildDetails: config.BuildDetails{
+					Ldflags: []string{"original"},
+				},
+				BuildDetailsOverrides: []config.BuildDetailsOverride{
+					{
+						Goos:   "linux",
+						Goarch: "mips",
+						BuildDetails: config.BuildDetails{
+							Ldflags: []string{"overridden"},
+						},
+					},
+				},
+			}, api.Options{
+				Goos:   "linux",
+				Goarch: "mips",
+				Gomips: "hardfloat",
+			},
+		)
+		require.NoError(t, err)
+		require.Equal(t, config.BuildDetails{
+			Ldflags: []string{"overridden"},
+			Env:     []string{},
+		}, dets)
+	})
+
 	t.Run("with goriscv64", func(t *testing.T) {
 		dets, err := withOverrides(
 			testctx.New(),
@@ -1508,6 +1595,36 @@ func TestOverrides(t *testing.T) {
 		}, dets)
 	})
 
+	t.Run("with goriscv64 unespecified", func(t *testing.T) {
+		dets, err := withOverrides(
+			testctx.New(),
+			config.Build{
+				BuildDetails: config.BuildDetails{
+					Ldflags: []string{"original"},
+				},
+				BuildDetailsOverrides: []config.BuildDetailsOverride{
+					{
+						Goos:      "linux",
+						Goarch:    "riscv64",
+						Goriscv64: "rva22u64",
+						BuildDetails: config.BuildDetails{
+							Ldflags: []string{"overridden"},
+						},
+					},
+				},
+			}, api.Options{
+				Goos:      "linux",
+				Goarch:    "riscv64",
+				Goriscv64: "rva22u64",
+			},
+		)
+		require.NoError(t, err)
+		require.Equal(t, config.BuildDetails{
+			Ldflags: []string{"overridden"},
+			Env:     []string{},
+		}, dets)
+	})
+
 	t.Run("with go386", func(t *testing.T) {
 		dets, err := withOverrides(
 			testctx.New(),
@@ -1537,6 +1654,36 @@ func TestOverrides(t *testing.T) {
 			Env:     []string{},
 		}, dets)
 	})
+
+	t.Run("with go386 unespecified", func(t *testing.T) {
+		dets, err := withOverrides(
+			testctx.New(),
+			config.Build{
+				BuildDetails: config.BuildDetails{
+					Ldflags: []string{"original"},
+				},
+				BuildDetailsOverrides: []config.BuildDetailsOverride{
+					{
+						Goos:   "linux",
+						Goarch: "386",
+						Go386:  "sse2",
+						BuildDetails: config.BuildDetails{
+							Ldflags: []string{"overridden"},
+						},
+					},
+				},
+			}, api.Options{
+				Goos:   "linux",
+				Goarch: "386",
+				Go386:  "sse2",
+			},
+		)
+		require.NoError(t, err)
+		require.Equal(t, config.BuildDetails{
+			Ldflags: []string{"overridden"},
+			Env:     []string{},
+		}, dets)
+	})
 }
 
 func TestWarnIfTargetsAndOtherOptionsTogether(t *testing.T) {
