@@ -37,19 +37,19 @@ func TestGitLabReleaseURLTemplate(t *testing.T) {
 			name:            "default_download_url",
 			downloadURL:     DefaultGitLabDownloadURL,
 			repo:            repo,
-			wantDownloadURL: "https://gitlab.com/owner/name/-/releases/{{ .Tag }}/downloads/{{ .ArtifactName }}",
+			wantDownloadURL: "https://gitlab.com/owner/name/-/releases/{{ urlPathEscape .Tag }}/downloads/{{ .ArtifactName }}",
 		},
 		{
 			name:            "default_download_url_no_owner",
 			downloadURL:     DefaultGitLabDownloadURL,
 			repo:            config.Repo{Name: "name"},
-			wantDownloadURL: "https://gitlab.com/name/-/releases/{{ .Tag }}/downloads/{{ .ArtifactName }}",
+			wantDownloadURL: "https://gitlab.com/name/-/releases/{{ urlPathEscape .Tag }}/downloads/{{ .ArtifactName }}",
 		},
 		{
 			name:            "download_url_template",
 			repo:            repo,
 			downloadURL:     "{{ .Env.GORELEASER_TEST_GITLAB_URLS_DOWNLOAD }}",
-			wantDownloadURL: "https://gitlab.mycompany.com/owner/name/-/releases/{{ .Tag }}/downloads/{{ .ArtifactName }}",
+			wantDownloadURL: "https://gitlab.mycompany.com/owner/name/-/releases/{{ urlPathEscape .Tag }}/downloads/{{ .ArtifactName }}",
 		},
 		{
 			name:        "download_url_template_invalid_value",
@@ -105,7 +105,7 @@ func TestGitLabURLsAPITemplate(t *testing.T) {
 			wantHost: "gitlab.com",
 		},
 		{
-			name:     "speicifed_api_env_key",
+			name:     "specified_api_env_key",
 			apiURL:   "https://gitlab.mycompany.com",
 			wantHost: "gitlab.mycompany.com",
 		},
@@ -248,6 +248,9 @@ func TestGitLabURLsDownloadTemplate(t *testing.T) {
 
 			tmpFile, err := os.CreateTemp(t.TempDir(), "")
 			require.NoError(t, err)
+			t.Cleanup(func() {
+				_ = tmpFile.Close()
+			})
 
 			client, err := newGitLab(ctx, ctx.Token)
 			require.NoError(t, err)
