@@ -6,9 +6,8 @@ import (
 
 	"github.com/caarlos0/log"
 	"github.com/charmbracelet/lipgloss"
-	"github.com/goreleaser/goreleaser/internal/golden"
-	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/golden"
+	"github.com/goreleaser/goreleaser/v2/internal/testctx"
 	"github.com/muesli/termenv"
 	"github.com/stretchr/testify/require"
 )
@@ -20,7 +19,7 @@ func TestNotice(t *testing.T) {
 	log.Log = log.New(&w)
 
 	log.Info("first")
-	ctx := context.New(config.Project{})
+	ctx := testctx.New()
 	Notice(ctx, "foo.bar.whatever: foobar")
 	log.Info("last")
 	require.True(t, ctx.Deprecated)
@@ -35,7 +34,7 @@ func TestNoticeCustom(t *testing.T) {
 	log.Log = log.New(&w)
 
 	log.Info("first")
-	ctx := context.New(config.Project{})
+	ctx := testctx.New()
 	NoticeCustom(ctx, "something-else", "some custom template with a url {{ .URL }}")
 	log.Info("last")
 	require.True(t, ctx.Deprecated)
