@@ -35,6 +35,7 @@ func start(tb testing.TB) {
 // TODO: this test is too big... split in smaller tests? Mainly the manifest ones...
 func TestRunPipe(t *testing.T) {
 	testlib.CheckPath(t, "docker")
+	testlib.SkipIfWindows(t, "images only available for windows")
 	type errChecker func(*testing.T, error)
 	shouldErr := func(msg string) errChecker {
 		return func(t *testing.T, err error) {
@@ -89,14 +90,14 @@ func TestRunPipe(t *testing.T) {
 					Goos:               "linux",
 					Goarch:             "amd64",
 					Dockerfile:         "testdata/Dockerfile.arch",
-					BuildFlagTemplates: []string{"--build-arg", "ARCH=amd64"},
+					BuildFlagTemplates: []string{"--build-arg", "ARCH=amd64", "--platform", "amd64"},
 				},
 				{
 					ImageTemplates:     []string{registry + "goreleaser/test_multiarch:test-arm64v8"},
 					Goos:               "linux",
 					Goarch:             "arm64",
 					Dockerfile:         "testdata/Dockerfile.arch",
-					BuildFlagTemplates: []string{"--build-arg", "ARCH=arm64v8"},
+					BuildFlagTemplates: []string{"--build-arg", "ARCH=arm64v8", "--platform", "arm64"},
 				},
 			},
 			manifests: []config.DockerManifest{
@@ -207,14 +208,14 @@ func TestRunPipe(t *testing.T) {
 					Goos:               "linux",
 					Goarch:             "amd64",
 					Dockerfile:         "testdata/Dockerfile.arch",
-					BuildFlagTemplates: []string{"--build-arg", "ARCH=amd64"},
+					BuildFlagTemplates: []string{"--build-arg", "ARCH=amd64", "--platform", "amd64"},
 				},
 				{
 					ImageTemplates:     []string{registry + "goreleaser/test_multiarch:2test-arm64v8"},
 					Goos:               "linux",
 					Goarch:             "arm64",
 					Dockerfile:         "testdata/Dockerfile.arch",
-					BuildFlagTemplates: []string{"--build-arg", "ARCH=arm64v8"},
+					BuildFlagTemplates: []string{"--build-arg", "ARCH=arm64v8", "--platform", "arm64"},
 				},
 			},
 			manifests: []config.DockerManifest{
@@ -257,7 +258,7 @@ func TestRunPipe(t *testing.T) {
 					Goos:               "linux",
 					Goarch:             "arm64",
 					Dockerfile:         "testdata/Dockerfile.arch",
-					BuildFlagTemplates: []string{"--build-arg", "ARCH=arm64v8"},
+					BuildFlagTemplates: []string{"--build-arg", "ARCH=arm64v8", "--platform", "arm64"},
 				},
 			},
 			manifests: []config.DockerManifest{
