@@ -15,6 +15,7 @@ import (
 	"github.com/stretchr/testify/assert"
 
 	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/gio"
 	"github.com/goreleaser/goreleaser/v2/internal/git"
 	"github.com/goreleaser/goreleaser/v2/internal/skips"
 	"github.com/goreleaser/goreleaser/v2/internal/testctx"
@@ -39,16 +40,15 @@ const (
 
 func TestMain(m *testing.M) {
 	rand := rand.New(rand.NewSource(time.Now().UnixNano()))
-	keyring = fmt.Sprintf("/tmp/gorel_gpg_test.%d", rand.Int())
+	keyring = filepath.Join(os.TempDir(), fmt.Sprintf("gorel_gpg_test.%d", rand.Int()))
 	fmt.Println("copying", originKeyring, "to", keyring)
-	if err := exec.Command("cp", "-Rf", originKeyring, keyring).Run(); err != nil {
+	if err := gio.Copy(originKeyring, keyring); err != nil {
 		fmt.Printf("failed to copy %s to %s: %s", originKeyring, keyring, err)
 		os.Exit(1)
 	}
 
-	code := m.Run()
+	m.Run()
 	_ = os.RemoveAll(keyring)
-	os.Exit(code)
 }
 
 func TestDescription(t *testing.T) {
@@ -97,6 +97,7 @@ func TestSignInvalidArtifacts(t *testing.T) {
 }
 
 func TestSignArtifacts(t *testing.T) {
+	testlib.SkipIfWindows(t, "tries to use /usr/bin/gpg-agent")
 	stdin := passwordUser
 	tmplStdin := passwordUserTmpl
 	tests := []struct {
@@ -728,7 +729,7 @@ func verifySignature(tb testing.TB, ctx *context.Context, sig string, user strin
 	artifact := strings.TrimSuffix(sig, filepath.Ext(sig))
 	artifact = strings.TrimSuffix(artifact, "."+fakeGPGKeyID)
 
-	// verify signature was made with key for usesr 'nopass'
+	// verify signature was made with key for user 'nopass'
 	cmd := exec.Command("gpg", "--homedir", keyring, "--verify", filepath.Join(ctx.Config.Dist, sig), filepath.Join(ctx.Config.Dist, artifact))
 	out, err := cmd.CombinedOutput()
 	require.NoError(tb, err, string(out))
