@@ -175,11 +175,11 @@ func TestRun(t *testing.T) {
 				NameTemplate: "foo",
 				Hooks: config.BuildHookConfig{
 					Pre: []config.Hook{
-						{Cmd: "touch " + pre},
+						{Cmd: testlib.Touch(pre)},
 					},
 					Post: []config.Hook{
-						{Cmd: "touch " + post},
-						{Cmd: `sh -c 'echo "{{ .Name }} {{ .Os }} {{ .Arch }} {{ .Arm }} {{ .Target }} {{ .Ext }}" > {{ .Path }}.post'`, Output: true},
+						{Cmd: testlib.Touch(post)},
+						{Cmd: testlib.ShC(`echo "{{ .Name }} {{ .Os }} {{ .Arch }} {{ .Arm }} {{ .Target }} {{ .Ext }}" > {{ .Path }}.post`), Output: true},
 					},
 				},
 			},
@@ -208,11 +208,14 @@ func TestRun(t *testing.T) {
 				ModTimestamp: fmt.Sprintf("%d", modTime.Unix()),
 				Hooks: config.BuildHookConfig{
 					Pre: []config.Hook{
-						{Cmd: "touch " + pre},
+						{Cmd: testlib.Touch(pre)},
 					},
 					Post: []config.Hook{
-						{Cmd: "touch " + post},
-						{Cmd: `sh -c 'echo "{{ .Name }} {{ .Os }} {{ .Arch }} {{ .Arm }} {{ .Target }} {{ .Ext }}" > {{ .Path }}.post'`, Output: true},
+						{Cmd: testlib.Touch(post)},
+						{
+							Cmd:    testlib.ShC(`echo "{{ .Name }} {{ .Os }} {{ .Arch }} {{ .Arm }} {{ .Target }} {{ .Ext }}" > {{ .Path }}.post`),
+							Output: true,
+						},
 					},
 				},
 			},
@@ -309,13 +312,13 @@ func TestRun(t *testing.T) {
 		require.FileExists(t, post)
 		bts, err := os.ReadFile(post)
 		require.NoError(t, err)
-		require.Equal(t, "foo darwin all  darwin_all \n", string(bts))
+		require.Contains(t, string(bts), "foo darwin all  darwin_all")
 	})
 
 	t.Run("failing pre-hook", func(t *testing.T) {
 		ctx := ctx5
 		ctx.Config.UniversalBinaries[0].Hooks.Pre = []config.Hook{{Cmd: "exit 1"}}
-		ctx.Config.UniversalBinaries[0].Hooks.Post = []config.Hook{{Cmd: "echo post"}}
+		ctx.Config.UniversalBinaries[0].Hooks.Post = []config.Hook{{Cmd: "doesnt-matter"}}
 		err := Pipe{}.Run(ctx)
 		require.ErrorIs(t, err, exec.ErrNotFound)
 		require.ErrorContains(t, err, "pre hook failed")
@@ -323,7 +326,7 @@ func TestRun(t *testing.T) {
 
 	t.Run("failing post-hook", func(t *testing.T) {
 		ctx := ctx5
-		ctx.Config.UniversalBinaries[0].Hooks.Pre = []config.Hook{{Cmd: "echo pre"}}
+		ctx.Config.UniversalBinaries[0].Hooks.Pre = []config.Hook{{Cmd: testlib.Echo("pre")}}
 		ctx.Config.UniversalBinaries[0].Hooks.Post = []config.Hook{{Cmd: "exit 1"}}
 		err := Pipe{}.Run(ctx)
 		require.ErrorIs(t, err, exec.ErrNotFound)
@@ -349,7 +352,7 @@ func TestRun(t *testing.T) {
 		ctx.Skips[string(skips.PostBuildHooks)] = false
 		ctx.Skips[string(skips.PreBuildHooks)] = false
 		ctx.Config.UniversalBinaries[0].Hooks.Pre = []config.Hook{{
-			Cmd: "echo {{.Env.FOO}}",
+			Cmd: testlib.Echo("{{.Env.FOO}}"),
 			Env: []string{"FOO=foo-{{.Tag}}"},
 		}}
 		ctx.Config.UniversalBinaries[0].Hooks.Post = []config.Hook{}
@@ -361,7 +364,7 @@ func TestRun(t *testing.T) {
 		ctx.Skips[string(skips.PostBuildHooks)] = false
 		ctx.Skips[string(skips.PreBuildHooks)] = false
 		ctx.Config.UniversalBinaries[0].Hooks.Pre = []config.Hook{{
-			Cmd: "echo blah",
+			Cmd: testlib.Echo("blah"),
 			Env: []string{"FOO=foo-{{.Tag}"},
 		}}
 		ctx.Config.UniversalBinaries[0].Hooks.Post = []config.Hook{}
@@ -371,7 +374,7 @@ func TestRun(t *testing.T) {
 	t.Run("hook with bad dir tmpl", func(t *testing.T) {
 		ctx := ctx5
 		ctx.Config.UniversalBinaries[0].Hooks.Pre = []config.Hook{{
-			Cmd: "echo blah",
+			Cmd: testlib.Echo("blah"),
 			Dir: "{{.Tag}",
 		}}
 		ctx.Config.UniversalBinaries[0].Hooks.Post = []config.Hook{}
@@ -381,7 +384,7 @@ func TestRun(t *testing.T) {
 	t.Run("hook with bad cmd tmpl", func(t *testing.T) {
 		ctx := ctx5
 		ctx.Config.UniversalBinaries[0].Hooks.Pre = []config.Hook{{
-			Cmd: "echo blah-{{.Tag }",
+			Cmd: testlib.Echo("blah-{{.Tag }"),
 		}}
 		ctx.Config.UniversalBinaries[0].Hooks.Post = []config.Hook{}
 		testlib.RequireTemplateError(t, Pipe{}.Run(ctx))
