@@ -945,7 +945,7 @@ type NFPMOverridables struct {
 	Recommends       []string       `yaml:"recommends,omitempty" json:"recommends,omitempty"`
 	Suggests         []string       `yaml:"suggests,omitempty" json:"suggests,omitempty"`
 	Conflicts        []string       `yaml:"conflicts,omitempty" json:"conflicts,omitempty"`
-	Umask            fs.FileMode    `yaml:"umask,omitempty" json:"umask,omitempty"`
+	Umask            fs.FileMode    `yaml:"umask,omitempty" json:"umask,omitempty" jsonschema:"oneof_type=string;integer"`
 	Replaces         []string       `yaml:"replaces,omitempty" json:"replaces,omitempty"`
 	Provides         []string       `yaml:"provides,omitempty" json:"provides,omitempty"`
 	Contents         files.Contents `yaml:"contents,omitempty" json:"contents,omitempty"`
@@ -1314,7 +1314,7 @@ type Announce struct {
 	LinkedIn       LinkedIn       `yaml:"linkedin,omitempty" json:"linkedin,omitempty"`
 	Telegram       Telegram       `yaml:"telegram,omitempty" json:"telegram,omitempty"`
 	Webhook        Webhook        `yaml:"webhook,omitempty" json:"webhook,omitempty"`
-	OpenCollective OpenCollective `yaml:"opencollective,omitempty" json:"opencolletive,omitempty"`
+	OpenCollective OpenCollective `yaml:"opencollective,omitempty" json:"opencollective,omitempty"`
 	Bluesky        Bluesky        `yaml:"bluesky,omitempty" json:"bluesky,omitempty"`
 }
 
@@ -1495,7 +1495,7 @@ type Chocolatey struct {
 	Goamd64                  string                 `yaml:"goamd64,omitempty" json:"goamd64,omitempty"`
 }
 
-// ChcolateyDependency represents Chocolatey dependency.
+// ChocolateyDependency represents Chocolatey dependency.
 type ChocolateyDependency struct {
 	ID      string `yaml:"id,omitempty" json:"id,omitempty"`
 	Version string `yaml:"version,omitempty" json:"version,omitempty"`
